==> apache-tapestry-5.6.4-sources.zip: tapestry-core/src/main/java/org/apache/tapestry5/internal/transform/InjectServiceWorker.java <==
// Copyright 2009, 2010, 2011 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.tapestry5.internal.transform;

import org.apache.tapestry5.internal.services.ComponentClassCache;
import org.apache.tapestry5.ioc.ObjectLocator;
import org.apache.tapestry5.ioc.annotations.InjectService;
import org.apache.tapestry5.model.MutableComponentModel;
import org.apache.tapestry5.plastic.PlasticClass;
import org.apache.tapestry5.plastic.PlasticField;
import org.apache.tapestry5.services.transform.ComponentClassTransformWorker2;
import org.apache.tapestry5.services.transform.TransformationSupport;

/**
 * Processes the {@link org.apache.tapestry5.ioc.annotations.InjectService} annotation.
 *
 * @since 5.1.0.0
 */
public class InjectServiceWorker implements ComponentClassTransformWorker2
{
    private final ObjectLocator locator;

    private final ComponentClassCache cache;

    public InjectServiceWorker(ObjectLocator locator, ComponentClassCache cache)
    {
        this.locator = locator;
        this.cache = cache;
    }

    public void transform(PlasticClass plasticClass, TransformationSupport support, MutableComponentModel model)
    {
        for (PlasticField field : plasticClass.getFieldsWithAnnotation(InjectService.class))
        {
            InjectService annotation = field.getAnnotation(InjectService.class);

            field.claim(annotation);

            Class fieldType = cache.forName(field.getTypeName());

            Object service = locator.getService(annotation.value(), fieldType);

            field.inject(service);
        }
    }
}

==> apache-tapestry-5.8.6-sources.zip: tapestry-core/src/main/java/org/apache/tapestry5/internal/transform/InjectServiceWorker.java <==
// Copyright 2009, 2010, 2011 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.tapestry5.internal.transform;

import org.apache.tapestry5.commons.ObjectLocator;
import org.apache.tapestry5.internal.services.ComponentClassCache;
import org.apache.tapestry5.ioc.annotations.InjectService;
import org.apache.tapestry5.model.MutableComponentModel;
import org.apache.tapestry5.plastic.PlasticClass;
import org.apache.tapestry5.plastic.PlasticField;
import org.apache.tapestry5.services.transform.ComponentClassTransformWorker2;
import org.apache.tapestry5.services.transform.TransformationSupport;

/**
 * Processes the {@link org.apache.tapestry5.ioc.annotations.InjectService} annotation.
 *
 * @since 5.1.0.0
 */
public class InjectServiceWorker implements ComponentClassTransformWorker2
{
    private final ObjectLocator locator;

    private final ComponentClassCache cache;

    public InjectServiceWorker(ObjectLocator locator, ComponentClassCache cache)
    {
        this.locator = locator;
        this.cache = cache;
    }

    public void transform(PlasticClass plasticClass, TransformationSupport support, MutableComponentModel model)
    {
        for (PlasticField field : plasticClass.getFieldsWithAnnotation(InjectService.class))
        {
            InjectService annotation = field.getAnnotation(InjectService.class);

            field.claim(annotation);

            Class fieldType = cache.forName(field.getTypeName());

            Object service = locator.getService(annotation.value(), fieldType);

            field.inject(service);
        }
    }
}
